#
# spec file for package ghc-fast-logger
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name fast-logger
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        3.2.5
Release:        1.4
Summary:        A fast logging system
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-array-prof
BuildRequires:  ghc-auto-update-devel
BuildRequires:  ghc-auto-update-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-easy-file-devel
BuildRequires:  ghc-easy-file-prof
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepath-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-stm-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-unix-compat-devel
BuildRequires:  ghc-unix-compat-prof
BuildRequires:  ghc-unix-time-devel
BuildRequires:  ghc-unix-time-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-async-prof
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
%endif

%description
A fast logging system for Haskell.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Oct 31 2024 Peter Simons <psimons@suse.com>
- Update fast-logger to version 3.2.5.
  [#]# 3.2.5
  * Giving names to threads.
* Tue Oct 15 2024 Peter Simons <psimons@suse.com>
- Update fast-logger to version 3.2.4.
  [#]# 3.2.4
  * Avoid unnecessary copy for Text values with text-2.0
    [#219](https://github.com/kazu-yamamoto/logger/pull/219)
* Thu May 16 2024 Peter Simons <psimons@suse.com>
- Update fast-logger to version 3.2.3.
  [#]# 3.2.3
  * Ensuring flush for single logger.
    [#214](https://github.com/kazu-yamamoto/logger/pull/214)
* Thu Jul  6 2023 Peter Simons <psimons@suse.com>
- Update fast-logger to version 3.2.2.
  [#]# 3.2.2
  * Corrected handling of messages at the buffer boundary in the SingleLogger
    [#211](https://github.com/kazu-yamamoto/logger/pull/211)
  [#]# 3.2.1
  * Fixing a bug where a single logger is not killed
  [#]# 3.2.0
  * newFastLogger1 ensures the ordering of logs
    [#207](https://github.com/kazu-yamamoto/logger/pull/207)
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Mon Feb  6 2023 Peter Simons <psimons@suse.com>
- Update fast-logger to version 3.1.2.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/fast-logger-3.1.2/src/ChangeLog.md
* Sun Jan 29 2023 Peter Simons <psimons@suse.com>
- Update fast-logger to version 3.1.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Jan 20 2022 Peter Simons <psimons@suse.com>
- Update fast-logger to version 3.1.1.
  [#]# 3.1.1
  * More time-ordered logging functions
    [#199](https://github.com/kazu-yamamoto/logger/pull/199
  [#]# 3.1.0
  * Having a single Buffer in LoggerSet for locking [#197](https://github.com/kazu-yamamoto/logger/pull/197.
    This would have performance penalty. So, the major version bumps up. If you see performance regression, please register an issue on github.
* Fri Apr 30 2021 psimons@suse.com
- Update fast-logger to version 3.0.5.
  [#]# 3.0.5
  * recovering backward compatibility for newFileLoggerSet.
* Wed Apr 28 2021 psimons@suse.com
- Update fast-logger to version 3.0.4.
  [#]# 3.0.4
  * New API: `newFastLogger1` which use only one capability.
  * Making `FD` safer with `invalidFD`.
* Fri Feb 19 2021 psimons@suse.com
- Update fast-logger to version 3.0.3.
  [#]# 3.0.3
  * Dropping support of GHC 7.x.
  * Add `ToLogStr` instance for `ShortByteString`. Add lower bound on
    `bytestring` dependency to ensure that `bytestring` exports
    `Data.ByteString.Short`.
  [#]# 3.0.2
  * Fixing documentation.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Sep 29 2020 psimons@suse.com
- Update fast-logger to version 3.0.2.
  Upstream has not updated the file "ChangeLog.md" since the last
  release.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun  9 2020 psimons@suse.com
- Add fast-logger at version 3.0.1.
